@@ -3,7 +3,10 @@
 setClass("AllItemsClass",
          representation(par='numeric',
                         SEpar='numeric',
+                        parnames='character',
                         est='logical',
+                        dps='function',
+                        dps2='function',
                         constr='logical',
                         itemclass='integer',
                         parnum='numeric',
@@ -56,8 +59,6 @@ setGeneric("logLik", function(object, ...) standardGeneric("logLik"))
 
 setGeneric('DrawValues', function(x, Theta, ...) standardGeneric("DrawValues"))
 
-setGeneric('RandomDeriv', function(x, ...) standardGeneric("RandomDeriv"))
-
 setGeneric('GenRandomPars', function(x) standardGeneric("GenRandomPars"))
 
 setGeneric('CheckIntercepts', function(x) standardGeneric("CheckIntercepts"))
