@@ -376,6 +376,7 @@ DRF <- function(mod, draws = NULL, focal_items = 1L:extract.mirt(mod, 'nitems'),
     details <- list(data = extract.mirt(mod, 'data'),
                     model = extract.mirt(mod, 'model'),
                     group = extract.mirt(mod, 'group'),
+                    constrain = extract.mirt(mod, 'constrain'),
                     itemtype = extract.mirt(mod, 'itemtype'),
                     technical = list(storeEtable=TRUE, theta_lim=theta_lim, omp=FALSE),
                     quadpts=quadpts, large=large, TOL = NaN)
@@ -462,7 +463,8 @@ calc_DRFs <- function(mod, Theta, DIF, plot, max_score, focal_items, details, rs
     if(plot) return(c(T1, T2))
     if(is.null(rs)){
         mod2 <- with(details, multipleGroup(data=data, model=model, group=group, itemtype=itemtype, large=large,
-                                            quadpts=quadpts, TOL=TOL, pars=mod2values(mod), technical=technical))
+                                            constrain=constrain, quadpts=quadpts, TOL=TOL,
+                                            pars=mod2values(mod), technical=technical))
         r1 <- rowSums(mod2@Internals$Etable[[1L]]$r1)
         r2 <- rowSums(mod2@Internals$Etable[[2L]]$r1)
     } else {
