@@ -28,6 +28,11 @@
 #' @param group a \code{character} or \code{factor} vector indicating group membership. If a \code{character}
 #'   vector is supplied this will be automatically transformed into a \code{\link{factor}} variable.
 #'   As well, the first level of the (factorized) grouping variable will be treated as the "reference" group
+#' @param itemtype can be same type of input as is documented in \code{\link{mirt}}, however may also be a
+#'   \code{ngroups} by \code{nitems} matrix specifying the type of IRT models for each group, respectively.
+#'   Rows of this input correspond to the levels of the \code{group} input. For mixture models the rows correspond
+#'   to the respective mixture grouping variables to be constructed, and the IRT models should be within these
+#'   mixtures
 #' @param invariance a character vector containing the following possible options:
 #'   \describe{
 #'     \item{\code{'free_mean'} or \code{'free_means'}}{freely estimate all latent means in all focal groups
@@ -358,7 +363,8 @@
 #' coef(zip, simplify=TRUE)
 #'
 #' }
-multipleGroup <- function(data, model, group, invariance = '', method = 'EM',
+multipleGroup <- function(data, model, group, itemtype = NULL,
+                          invariance = '', method = 'EM',
                           dentype = 'Gaussian', ...)
 {
     Call <- match.call()
@@ -386,7 +392,7 @@ multipleGroup <- function(data, model, group, invariance = '', method = 'EM',
     }
     if(grepl('mixture', dentype)) group <- rep('full', nrow(data))
     mod <- ESTIMATION(data=data, model=model, group=group, invariance=invariance, method=method,
-                      dentype=dentype, ...)
+                      itemtype=itemtype, dentype=dentype, ...)
     if(is(mod, 'MultipleGroupClass') || is(mod, 'MixtureClass'))
         mod@Call <- Call
     return(mod)
